# Common configuration for Tmux users

{ config, pkgs, ... }:

{

  programs = {
    tmux = {   # Terminal multiplexer required by byobu
      enable = true;
      aggressiveResize = true;
      clock24 = true;
      extraConfig = ''
        #POWERLINE_COMMAND="/run/current-system/sw/bin/powerline"
        #POWERLINE_CONFIG_COMMAND="/run/current-system/sw/bin/powerline-config"
        #run-shell "/run/current-system/sw/bin/powerline-daemon -q"
        #source /run/current-system/sw/share/tmux/powerline.conf

        # Plugins
        set -g @plugin 'tmux-plugins/tmux-resurrect'
        set -g @plugin 'tmux-plugins/tmux-continuum'
        set -g @plugin 'dracula/tmux'

        set -g @dracula-show-battery false
        set -g @dracula-show-powerline true
        set -g @dracula-refresh-rate 10

        # Bind home and end keys:
        bind-key -n Home send Escape "OH"
        bind-key -n End send Escape "OF"
      '';
      keyMode    = "vi";
      newSession = true;
      shortcut   = "a";
      terminal   = "screen-256color";
    };
  };

  environment.systemPackages = with pkgs; [
    tmuxPlugins.continuum
    tmuxPlugins.dracula
    tmuxPlugins.resurrect
    tmuxPlugins.sensible
    tmuxPlugins.tmux-fzf
    tmuxPlugins.yank
  ];

}
